# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails from dynamically allocated email addresses. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://www.mailslurp.com/docs/) - [Examples](https://github.com/mailslurp/examples) repository   # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class InboxForwarderTestResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'does_match': 'bool',
        'matches': 'dict(str, bool)'
    }

    attribute_map = {
        'does_match': 'doesMatch',
        'matches': 'matches'
    }

    def __init__(self, does_match=None, matches=None, local_vars_configuration=None):  # noqa: E501
        """InboxForwarderTestResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._does_match = None
        self._matches = None
        self.discriminator = None

        self.does_match = does_match
        self.matches = matches

    @property
    def does_match(self):
        """Gets the does_match of this InboxForwarderTestResult.  # noqa: E501


        :return: The does_match of this InboxForwarderTestResult.  # noqa: E501
        :rtype: bool
        """
        return self._does_match

    @does_match.setter
    def does_match(self, does_match):
        """Sets the does_match of this InboxForwarderTestResult.


        :param does_match: The does_match of this InboxForwarderTestResult.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and does_match is None:  # noqa: E501
            raise ValueError("Invalid value for `does_match`, must not be `None`")  # noqa: E501

        self._does_match = does_match

    @property
    def matches(self):
        """Gets the matches of this InboxForwarderTestResult.  # noqa: E501


        :return: The matches of this InboxForwarderTestResult.  # noqa: E501
        :rtype: dict(str, bool)
        """
        return self._matches

    @matches.setter
    def matches(self, matches):
        """Sets the matches of this InboxForwarderTestResult.


        :param matches: The matches of this InboxForwarderTestResult.  # noqa: E501
        :type: dict(str, bool)
        """
        if self.local_vars_configuration.client_side_validation and matches is None:  # noqa: E501
            raise ValueError("Invalid value for `matches`, must not be `None`")  # noqa: E501

        self._matches = matches

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InboxForwarderTestResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InboxForwarderTestResult):
            return True

        return self.to_dict() != other.to_dict()
